# Documentation
- [ ] Usage
- [ ] Development
- [ ] Adding new flows
- [ ] Developer docs for adding new flows

# Main code

- [ ] FIX lingering child processes after being killed
- [x] Idea: Some code in Suite should be refactored to a FlowRunner class, suites/flows? should provide a run method.
- [x] parallel runs
- [.] Flow chaining
- [ ] move DSE code to a plugin
- [ ] Installation / set-up of tools
- [ ] Run in docker

## Flows

- [.] Support multiple clocks in synthesis at least with DefaultRunner
- [x] Modelsim
- [.] ghdl + yosys + nextpnr-ecp5
- [ ] Synopsys VCS
- [.] Synopsys DC
- [ ] Synopsys ICC2
- [ ] OpenROAD/OpenLANE
- [x] Quartus: Power estimation
